==> gmic_3.0.1.tar.gz: gmic-3.0.1/gmic-qt/src/FilterSelector/FiltersModelReader.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FiltersModelReader.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERSMODELREADER_H
#define GMIC_QT_FILTERSMODELREADER_H
#include <QString>
#include "FilterSelector/FiltersModel.h"

class QByteArray;
class QBuffer;

namespace GmicQt
{

class FiltersModelReader {
public:
  FiltersModelReader(FiltersModel & model);
  void parseFiltersDefinitions(QByteArray & stdlibArray);

private:
  FiltersModel & _model;
  static QString readBufferLine(QBuffer &);
  static bool textIsPrecededBySpacesInSomeLineOfArray(const QByteArray & text, const QByteArray & array);
  static InputMode symbolToInputMode(const QString & str);
};

} // namespace GmicQt

#endif // GMIC_QT_FILTERSMODELREADER_H

==> gmic_3.6.6.tar.gz: gmic-3.6.6/gmic-qt/src/FilterSelector/FiltersModelReader.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FiltersModelReader.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERSMODELREADER_H
#define GMIC_QT_FILTERSMODELREADER_H
#include <QString>
#include "FilterSelector/FiltersModel.h"

class QByteArray;
class QBuffer;

namespace GmicQt
{

class FiltersModelReader {
public:
  FiltersModelReader(FiltersModel & model);
  void parseFiltersDefinitions(const QByteArray &stdlibArray);

private:
  FiltersModel & _model;
  static QString readBufferLine(QBuffer &);
  static QString readBufferLine(const char *& ptr, const char * limit);
  static bool textIsPrecededBySpacesInSomeLineOfArray(const QByteArray & text, const QByteArray & array);
  static InputMode symbolToInputMode(const QString & str);
};

} // namespace GmicQt

#endif // GMIC_QT_FILTERSMODELREADER_H
